You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by lu...@apache.org on 2011/12/01 08:27:13 UTC

svn commit: r1208981 [12/24] - in /struts/struts2/branches/STRUTS_3_X: apps/blank/src/main/java/example/ apps/blank/src/test/java/example/ apps/jboss-blank/src/main/java/example/ apps/jboss-blank/src/test/java/example/ apps/mailreader/src/main/java/mai...

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/providers/XWorkConfigurationProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/providers/XWorkConfigurationProvider.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/providers/XWorkConfigurationProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/providers/XWorkConfigurationProvider.java Thu Dec  1 07:18:07 2011
@@ -1,51 +1,51 @@
-package com.opensymphony.xwork2.config.providers;
+package org.apache.struts2.xwork2.config.providers;
 
-import com.opensymphony.xwork2.ActionProxyFactory;
-import com.opensymphony.xwork2.DefaultActionProxyFactory;
-import com.opensymphony.xwork2.DefaultTextProvider;
-import com.opensymphony.xwork2.DefaultUnknownHandlerManager;
-import com.opensymphony.xwork2.TextProvider;
-import com.opensymphony.xwork2.TextProviderSupport;
-import com.opensymphony.xwork2.UnknownHandlerManager;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.ConfigurationProvider;
-import com.opensymphony.xwork2.conversion.NullHandler;
-import com.opensymphony.xwork2.conversion.ObjectTypeDeterminer;
-import com.opensymphony.xwork2.conversion.impl.DefaultObjectTypeDeterminer;
-import com.opensymphony.xwork2.conversion.impl.InstantiatingNullHandler;
-import com.opensymphony.xwork2.conversion.impl.XWorkBasicConverter;
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
-import com.opensymphony.xwork2.inject.ContainerBuilder;
-import com.opensymphony.xwork2.inject.Scope;
-import com.opensymphony.xwork2.ognl.ObjectProxy;
-import com.opensymphony.xwork2.ognl.OgnlReflectionContextFactory;
-import com.opensymphony.xwork2.ognl.OgnlReflectionProvider;
-import com.opensymphony.xwork2.ognl.OgnlUtil;
-import com.opensymphony.xwork2.ognl.OgnlValueStackFactory;
-import com.opensymphony.xwork2.ognl.accessor.CompoundRootAccessor;
-import com.opensymphony.xwork2.ognl.accessor.ObjectAccessor;
-import com.opensymphony.xwork2.ognl.accessor.ObjectProxyPropertyAccessor;
-import com.opensymphony.xwork2.ognl.accessor.XWorkCollectionPropertyAccessor;
-import com.opensymphony.xwork2.ognl.accessor.XWorkEnumerationAccessor;
-import com.opensymphony.xwork2.ognl.accessor.XWorkIteratorPropertyAccessor;
-import com.opensymphony.xwork2.ognl.accessor.XWorkListPropertyAccessor;
-import com.opensymphony.xwork2.ognl.accessor.XWorkMapPropertyAccessor;
-import com.opensymphony.xwork2.ognl.accessor.XWorkMethodAccessor;
-import com.opensymphony.xwork2.util.CompoundRoot;
-import com.opensymphony.xwork2.util.PatternMatcher;
-import com.opensymphony.xwork2.util.ValueStackFactory;
-import com.opensymphony.xwork2.util.WildcardHelper;
-import com.opensymphony.xwork2.util.location.LocatableProperties;
-import com.opensymphony.xwork2.util.reflection.ReflectionContextFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionProvider;
-import com.opensymphony.xwork2.validator.ActionValidatorManager;
-import com.opensymphony.xwork2.validator.AnnotationActionValidatorManager;
-import com.opensymphony.xwork2.validator.DefaultActionValidatorManager;
-import com.opensymphony.xwork2.validator.DefaultValidatorFactory;
-import com.opensymphony.xwork2.validator.DefaultValidatorFileParser;
-import com.opensymphony.xwork2.validator.ValidatorFactory;
-import com.opensymphony.xwork2.validator.ValidatorFileParser;
+import org.apache.struts2.xwork2.ActionProxyFactory;
+import org.apache.struts2.xwork2.DefaultActionProxyFactory;
+import org.apache.struts2.xwork2.DefaultTextProvider;
+import org.apache.struts2.xwork2.DefaultUnknownHandlerManager;
+import org.apache.struts2.xwork2.TextProvider;
+import org.apache.struts2.xwork2.TextProviderSupport;
+import org.apache.struts2.xwork2.UnknownHandlerManager;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.ConfigurationProvider;
+import org.apache.struts2.xwork2.conversion.NullHandler;
+import org.apache.struts2.xwork2.conversion.ObjectTypeDeterminer;
+import org.apache.struts2.xwork2.conversion.impl.DefaultObjectTypeDeterminer;
+import org.apache.struts2.xwork2.conversion.impl.InstantiatingNullHandler;
+import org.apache.struts2.xwork2.conversion.impl.XWorkBasicConverter;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.inject.ContainerBuilder;
+import org.apache.struts2.xwork2.inject.Scope;
+import org.apache.struts2.xwork2.ognl.ObjectProxy;
+import org.apache.struts2.xwork2.ognl.OgnlReflectionContextFactory;
+import org.apache.struts2.xwork2.ognl.OgnlReflectionProvider;
+import org.apache.struts2.xwork2.ognl.OgnlUtil;
+import org.apache.struts2.xwork2.ognl.OgnlValueStackFactory;
+import org.apache.struts2.xwork2.ognl.accessor.CompoundRootAccessor;
+import org.apache.struts2.xwork2.ognl.accessor.ObjectAccessor;
+import org.apache.struts2.xwork2.ognl.accessor.ObjectProxyPropertyAccessor;
+import org.apache.struts2.xwork2.ognl.accessor.XWorkCollectionPropertyAccessor;
+import org.apache.struts2.xwork2.ognl.accessor.XWorkEnumerationAccessor;
+import org.apache.struts2.xwork2.ognl.accessor.XWorkIteratorPropertyAccessor;
+import org.apache.struts2.xwork2.ognl.accessor.XWorkListPropertyAccessor;
+import org.apache.struts2.xwork2.ognl.accessor.XWorkMapPropertyAccessor;
+import org.apache.struts2.xwork2.ognl.accessor.XWorkMethodAccessor;
+import org.apache.struts2.xwork2.util.CompoundRoot;
+import org.apache.struts2.xwork2.util.PatternMatcher;
+import org.apache.struts2.xwork2.util.ValueStackFactory;
+import org.apache.struts2.xwork2.util.WildcardHelper;
+import org.apache.struts2.xwork2.util.location.LocatableProperties;
+import org.apache.struts2.xwork2.util.reflection.ReflectionContextFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionProvider;
+import org.apache.struts2.xwork2.validator.ActionValidatorManager;
+import org.apache.struts2.xwork2.validator.AnnotationActionValidatorManager;
+import org.apache.struts2.xwork2.validator.DefaultActionValidatorManager;
+import org.apache.struts2.xwork2.validator.DefaultValidatorFactory;
+import org.apache.struts2.xwork2.validator.DefaultValidatorFileParser;
+import org.apache.struts2.xwork2.validator.ValidatorFactory;
+import org.apache.struts2.xwork2.validator.ValidatorFileParser;
 import ognl.MethodAccessor;
 import ognl.PropertyAccessor;
 
@@ -77,7 +77,7 @@ public class XWorkConfigurationProvider 
     public void register(ContainerBuilder builder, LocatableProperties props)
             throws ConfigurationException {
 
-        builder.factory(com.opensymphony.xwork2.ObjectFactory.class)
+        builder.factory(org.apache.struts2.xwork2.ObjectFactory.class)
                 .factory(ActionProxyFactory.class, DefaultActionProxyFactory.class, Scope.SINGLETON)
                 .factory(ObjectTypeDeterminer.class, DefaultObjectTypeDeterminer.class, Scope.SINGLETON)
                 .factory(XWorkConverter.class, Scope.SINGLETON)

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/providers/XmlConfigurationProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/providers/XmlConfigurationProvider.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/providers/XmlConfigurationProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/providers/XmlConfigurationProvider.java Thu Dec  1 07:18:07 2011
@@ -13,28 +13,28 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.config.providers;
+package org.apache.struts2.xwork2.config.providers;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.XWorkException;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.ConfigurationProvider;
-import com.opensymphony.xwork2.config.ConfigurationUtil;
-import com.opensymphony.xwork2.config.entities.*;
-import com.opensymphony.xwork2.config.entities.UnknownHandlerConfig;
-import com.opensymphony.xwork2.config.impl.LocatableFactory;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.ContainerBuilder;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.inject.Scope;
-import com.opensymphony.xwork2.util.*;
-import com.opensymphony.xwork2.util.location.LocatableProperties;
-import com.opensymphony.xwork2.util.location.Location;
-import com.opensymphony.xwork2.util.location.LocationUtils;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.XWorkException;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.ConfigurationProvider;
+import org.apache.struts2.xwork2.config.ConfigurationUtil;
+import org.apache.struts2.xwork2.config.entities.*;
+import org.apache.struts2.xwork2.config.entities.UnknownHandlerConfig;
+import org.apache.struts2.xwork2.config.impl.LocatableFactory;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.ContainerBuilder;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.inject.Scope;
+import org.apache.struts2.xwork2.util.*;
+import org.apache.struts2.xwork2.util.location.LocatableProperties;
+import org.apache.struts2.xwork2.util.location.Location;
+import org.apache.struts2.xwork2.util.location.LocationUtils;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/providers/XmlHelper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/providers/XmlHelper.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/providers/XmlHelper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/config/providers/XmlHelper.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.config.providers;
+package org.apache.struts2.xwork2.config.providers;
 
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/NullHandler.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/NullHandler.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/NullHandler.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/NullHandler.java Thu Dec  1 07:18:07 2011
@@ -28,7 +28,7 @@
 //THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 //DAMAGE.
 //--------------------------------------------------------------------------
-package com.opensymphony.xwork2.conversion;
+package org.apache.struts2.xwork2.conversion;
 
 import java.util.Map;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/ObjectTypeDeterminer.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/ObjectTypeDeterminer.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/ObjectTypeDeterminer.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/ObjectTypeDeterminer.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.conversion;
+package org.apache.struts2.xwork2.conversion;
 
 /**
  * Determines what the key and and element class of a Map or Collection should be. For Maps, the elements are the

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/TypeConversionException.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/TypeConversionException.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/TypeConversionException.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/TypeConversionException.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.conversion;
+package org.apache.struts2.xwork2.conversion;
 
-import com.opensymphony.xwork2.XWorkException;
+import org.apache.struts2.xwork2.XWorkException;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/TypeConverter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/TypeConverter.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/TypeConverter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/TypeConverter.java Thu Dec  1 07:18:07 2011
@@ -28,7 +28,7 @@
 //  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 //  DAMAGE.
 //--------------------------------------------------------------------------
-package com.opensymphony.xwork2.conversion;
+package org.apache.struts2.xwork2.conversion;
 
 import java.lang.reflect.Member;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/Conversion.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/Conversion.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/Conversion.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/Conversion.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.conversion.annotations;
+package org.apache.struts2.xwork2.conversion.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/ConversionRule.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/ConversionRule.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/ConversionRule.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/ConversionRule.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.conversion.annotations;
+package org.apache.struts2.xwork2.conversion.annotations;
 
 /**
  * <code>ConversionRule</code>

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/ConversionType.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/ConversionType.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/ConversionType.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/ConversionType.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.conversion.annotations;
+package org.apache.struts2.xwork2.conversion.annotations;
 
 /**
  * <code>ConversionType</code>

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/TypeConversion.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/TypeConversion.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/TypeConversion.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/annotations/TypeConversion.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.conversion.annotations;
+package org.apache.struts2.xwork2.conversion.annotations;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;
@@ -157,7 +157,7 @@ public @interface TypeConversion {
      * The ConversionRule can be a PROPERTY, KEY, KEY_PROPERTY, ELEMENT, COLLECTION (deprecated) or a MAP.
      * Note: Collection and Map vonversion rules can be determined via com.opensymphony.xwork2.util.DefaultObjectTypeDeterminer.
      *
-     * @see com.opensymphony.xwork2.conversion.impl.DefaultObjectTypeDeterminer
+     * @see org.apache.struts2.xwork2.conversion.impl.DefaultObjectTypeDeterminer
      */
     ConversionRule rule() default ConversionRule.PROPERTY;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/DefaultObjectTypeDeterminer.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/DefaultObjectTypeDeterminer.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/DefaultObjectTypeDeterminer.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/DefaultObjectTypeDeterminer.java Thu Dec  1 07:18:07 2011
@@ -13,18 +13,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.conversion.impl;
+package org.apache.struts2.xwork2.conversion.impl;
 
-import com.opensymphony.xwork2.conversion.ObjectTypeDeterminer;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.CreateIfNull;
-import com.opensymphony.xwork2.util.Element;
-import com.opensymphony.xwork2.util.Key;
-import com.opensymphony.xwork2.util.KeyProperty;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionException;
-import com.opensymphony.xwork2.util.reflection.ReflectionProvider;
+import org.apache.struts2.xwork2.conversion.ObjectTypeDeterminer;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.CreateIfNull;
+import org.apache.struts2.xwork2.util.Element;
+import org.apache.struts2.xwork2.util.Key;
+import org.apache.struts2.xwork2.util.KeyProperty;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionException;
+import org.apache.struts2.xwork2.util.reflection.ReflectionProvider;
 
 import java.beans.IntrospectionException;
 import java.lang.annotation.Annotation;
@@ -81,7 +81,7 @@ public class DefaultObjectTypeDeterminer
      *
      * @param parentClass the Class which contains as a property the Map or Collection we are finding the key for.
      * @param property    the property of the Map or Collection for the given parent class
-     * @see com.opensymphony.xwork2.conversion.ObjectTypeDeterminer#getKeyClass(Class, String)
+     * @see org.apache.struts2.xwork2.conversion.ObjectTypeDeterminer#getKeyClass(Class, String)
      */
     public Class getKeyClass(Class parentClass, String property) {
         Key annotation = getAnnotation(parentClass, property, Key.class);
@@ -110,7 +110,7 @@ public class DefaultObjectTypeDeterminer
      *
      * @param parentClass the Class which contains as a property the Map or Collection we are finding the key for.
      * @param property    the property of the Map or Collection for the given parent class
-     * @see com.opensymphony.xwork2.conversion.ObjectTypeDeterminer#getElementClass(Class, String, Object)
+     * @see org.apache.struts2.xwork2.conversion.ObjectTypeDeterminer#getElementClass(Class, String, Object)
      */
     public Class getElementClass(Class parentClass, String property, Object key) {
         Element annotation = getAnnotation(parentClass, property, Element.class);
@@ -148,7 +148,7 @@ public class DefaultObjectTypeDeterminer
      *
      * @param parentClass the Class which contains as a property the Map or Collection we are finding the key for.
      * @param property    the property of the Map or Collection for the given parent class
-     * @see com.opensymphony.xwork2.conversion.ObjectTypeDeterminer#getKeyProperty(Class, String)
+     * @see org.apache.struts2.xwork2.conversion.ObjectTypeDeterminer#getKeyProperty(Class, String)
      */
     public String getKeyProperty(Class parentClass, String property) {
         KeyProperty annotation = getAnnotation(parentClass, property, KeyProperty.class);

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/DefaultTypeConverter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/DefaultTypeConverter.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/DefaultTypeConverter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/DefaultTypeConverter.java Thu Dec  1 07:18:07 2011
@@ -28,10 +28,10 @@
 //  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 //  DAMAGE.
 //--------------------------------------------------------------------------
-package com.opensymphony.xwork2.conversion.impl;
+package org.apache.struts2.xwork2.conversion.impl;
 
-import com.opensymphony.xwork2.conversion.TypeConverter;
-import com.opensymphony.xwork2.ognl.XWorkTypeConverterWrapper;
+import org.apache.struts2.xwork2.conversion.TypeConverter;
+import org.apache.struts2.xwork2.ognl.XWorkTypeConverterWrapper;
 
 import java.lang.reflect.Array;
 import java.lang.reflect.Member;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/EnumTypeConverter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/EnumTypeConverter.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/EnumTypeConverter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/EnumTypeConverter.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.conversion.impl;
+package org.apache.struts2.xwork2.conversion.impl;
 
 import java.util.Map;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/GenericsObjectTypeDeterminer.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/GenericsObjectTypeDeterminer.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/GenericsObjectTypeDeterminer.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/GenericsObjectTypeDeterminer.java Thu Dec  1 07:18:07 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.conversion.impl;
+package org.apache.struts2.xwork2.conversion.impl;
 
-import com.opensymphony.xwork2.util.reflection.ReflectionProvider;
+import org.apache.struts2.xwork2.util.reflection.ReflectionProvider;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/InstantiatingNullHandler.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/InstantiatingNullHandler.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/XWorkBasicConverter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/XWorkBasicConverter.java Thu Dec  1 07:18:07 2011
@@ -13,15 +13,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.conversion.impl;
+package org.apache.struts2.xwork2.conversion.impl;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.XWorkException;
-import com.opensymphony.xwork2.conversion.ObjectTypeDeterminer;
-import com.opensymphony.xwork2.conversion.TypeConverter;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.XWorkList;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.XWorkException;
+import org.apache.struts2.xwork2.conversion.ObjectTypeDeterminer;
+import org.apache.struts2.xwork2.conversion.TypeConverter;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.XWorkList;
 
 import java.lang.reflect.Array;
 import java.lang.reflect.Constructor;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/XWorkConverter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/XWorkConverter.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/XWorkConverter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/XWorkConverter.java Thu Dec  1 07:18:07 2011
@@ -13,23 +13,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.conversion.impl;
+package org.apache.struts2.xwork2.conversion.impl;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.XWorkMessages;
-import com.opensymphony.xwork2.XWorkException;
-import com.opensymphony.xwork2.conversion.TypeConverter;
-import com.opensymphony.xwork2.conversion.annotations.Conversion;
-import com.opensymphony.xwork2.conversion.annotations.ConversionRule;
-import com.opensymphony.xwork2.conversion.annotations.ConversionType;
-import com.opensymphony.xwork2.conversion.annotations.TypeConversion;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.ognl.XWorkTypeConverterWrapper;
-import com.opensymphony.xwork2.util.*;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionContextState;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.XWorkMessages;
+import org.apache.struts2.xwork2.XWorkException;
+import org.apache.struts2.xwork2.conversion.TypeConverter;
+import org.apache.struts2.xwork2.conversion.annotations.Conversion;
+import org.apache.struts2.xwork2.conversion.annotations.ConversionRule;
+import org.apache.struts2.xwork2.conversion.annotations.ConversionType;
+import org.apache.struts2.xwork2.conversion.annotations.TypeConversion;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.ognl.XWorkTypeConverterWrapper;
+import org.apache.struts2.xwork2.util.*;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionContextState;
 
 import java.io.IOException;
 import java.io.InputStream;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/metadata/ConversionDescription.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/metadata/ConversionDescription.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/metadata/ConversionDescription.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/metadata/ConversionDescription.java Thu Dec  1 07:18:07 2011
@@ -13,12 +13,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.conversion.metadata;
+package org.apache.struts2.xwork2.conversion.metadata;
 
-import com.opensymphony.xwork2.conversion.annotations.ConversionRule;
-import com.opensymphony.xwork2.conversion.impl.DefaultObjectTypeDeterminer;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.conversion.annotations.ConversionRule;
+import org.apache.struts2.xwork2.conversion.impl.DefaultObjectTypeDeterminer;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.io.PrintWriter;
 import java.io.StringWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ConstructionContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ConstructionContext.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ConstructionContext.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ConstructionContext.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
 import java.lang.reflect.InvocationHandler;
 import java.lang.reflect.InvocationTargetException;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Container.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Container.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Container.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Container.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
 import java.io.Serializable;
 import java.util.Set;
@@ -84,7 +84,7 @@ public interface Container extends Seria
 
   /**
    * Gets an instance of the given dependency which was declared in
-   * {@link com.opensymphony.xwork2.inject.ContainerBuilder}.
+   * {@link org.apache.struts2.xwork2.inject.ContainerBuilder}.
    */
   <T> T getInstance(Class<T> type, String name);
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ContainerBuilder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ContainerBuilder.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ContainerBuilder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ContainerBuilder.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
 import java.lang.reflect.Member;
 import java.util.*;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ContainerImpl.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ContainerImpl.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ContainerImpl.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ContainerImpl.java Thu Dec  1 07:18:07 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
-import com.opensymphony.xwork2.inject.util.ReferenceCache;
+import org.apache.struts2.xwork2.inject.util.ReferenceCache;
 
 import java.io.Serializable;
 import java.lang.annotation.Annotation;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Context.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Context.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Context.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Context.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
 import java.lang.reflect.Member;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/DependencyException.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/DependencyException.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/DependencyException.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/DependencyException.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
 /**
  * Thrown when a dependency is misconfigured.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ExternalContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ExternalContext.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ExternalContext.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/ExternalContext.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
 import java.lang.reflect.Member;
 import java.util.LinkedHashMap;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Factory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Factory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Factory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Factory.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
 /**
  * A custom factory. Creates objects which will be injected.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Inject.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Inject.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Inject.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Inject.java Thu Dec  1 07:18:07 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
-import static com.opensymphony.xwork2.inject.Container.DEFAULT_NAME;
+import static org.apache.struts2.xwork2.inject.Container.DEFAULT_NAME;
 
 import static java.lang.annotation.ElementType.*;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/InternalContext.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/InternalContext.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/InternalContext.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/InternalContext.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
 import java.util.HashMap;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/InternalFactory.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/InternalFactory.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/InternalFactory.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/InternalFactory.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
 import java.io.Serializable;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Key.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Key.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Key.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Key.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
 /**
  * Dependency mapping key. Uniquely identified by the required type and name.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Scope.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Scope.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Scope.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Scope.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
 import java.util.concurrent.Callable;
 
@@ -189,7 +189,7 @@ public enum Scope {
    * Pluggable scoping strategy. Enables users to provide custom
    * implementations of request, session, and wizard scopes. Implement and
    * pass to {@link
-   * Container#setScopeStrategy(com.opensymphony.xwork2.inject.Scope.Strategy)}.
+   * Container#setScopeStrategy(org.apache.struts2.xwork2.inject.Scope.Strategy)}.
    */
   public interface Strategy {
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Scoped.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Scoped.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Scoped.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/Scoped.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;
 
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Retention;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/package-info.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/package-info.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/package-info.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/package-info.java Thu Dec  1 07:18:07 2011
@@ -27,4 +27,4 @@
  *   <li>externalize what needs to be and no more</li>
  * </ul>
  */
-package com.opensymphony.xwork2.inject;
+package org.apache.struts2.xwork2.inject;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizablePhantomReference.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizablePhantomReference.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableReference.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableReference.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject.util;
+package org.apache.struts2.xwork2.inject.util;
 
 /**
  * Package-private interface implemented by references that have code to run

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableReferenceQueue.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableReferenceQueue.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableReferenceQueue.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableReferenceQueue.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject.util;
+package org.apache.struts2.xwork2.inject.util;
 
 import java.lang.ref.Reference;
 import java.lang.ref.ReferenceQueue;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableSoftReference.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableSoftReference.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/Function.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/Function.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject.util;
+package org.apache.struts2.xwork2.inject.util;
 
 /**
  * A Function provides a transformation on an object and returns the resulting

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/ReferenceCache.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/ReferenceCache.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/ReferenceCache.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/ReferenceCache.java Thu Dec  1 07:18:07 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject.util;
+package org.apache.struts2.xwork2.inject.util;
 
-import static com.opensymphony.xwork2.inject.util.ReferenceType.STRONG;
+import static org.apache.struts2.xwork2.inject.util.ReferenceType.STRONG;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/ReferenceMap.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/ReferenceMap.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/ReferenceMap.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/ReferenceMap.java Thu Dec  1 07:18:07 2011
@@ -14,9 +14,9 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject.util;
+package org.apache.struts2.xwork2.inject.util;
 
-import static com.opensymphony.xwork2.inject.util.ReferenceType.STRONG;
+import static org.apache.struts2.xwork2.inject.util.ReferenceType.STRONG;
 
 import java.io.IOException;
 import java.io.ObjectInputStream;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/ReferenceType.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/ReferenceType.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/ReferenceType.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/ReferenceType.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject.util;
+package org.apache.struts2.xwork2.inject.util;
 
 /**
  * Reference type. Used to specify what type of reference to keep to a

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/Strings.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/Strings.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/Strings.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/Strings.java Thu Dec  1 07:18:07 2011
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject.util;
+package org.apache.struts2.xwork2.inject.util;
 
 /**
  * String utilities.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ChainingInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ChainingInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ChainingInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ChainingInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,18 +13,18 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionChainResult;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.Result;
-import com.opensymphony.xwork2.Unchainable;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.CompoundRoot;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionProvider;
+import org.apache.struts2.xwork2.ActionChainResult;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.Result;
+import org.apache.struts2.xwork2.Unchainable;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.CompoundRoot;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionProvider;
 
 import java.util.*;
 
@@ -96,7 +96,7 @@ import java.util.*;
  *
  * @author mrdon
  * @author tm_jee ( tm_jee(at)yahoo.co.uk )
- * @see com.opensymphony.xwork2.ActionChainResult
+ * @see org.apache.struts2.xwork2.ActionChainResult
  */
 public class ChainingInterceptor extends AbstractInterceptor {
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ConversionErrorInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ConversionErrorInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ConversionErrorInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ConversionErrorInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,13 +13,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ValidationAware;
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ValidationAware;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.util.ValueStack;
 import org.apache.commons.lang.StringEscapeUtils;
 
 import java.util.HashMap;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/DefaultWorkflowInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/DefaultWorkflowInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/DefaultWorkflowInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/DefaultWorkflowInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,14 +13,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ValidationAware;
-import com.opensymphony.xwork2.interceptor.annotations.InputConfig;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ValidationAware;
+import org.apache.struts2.xwork2.interceptor.annotations.InputConfig;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.lang.reflect.Method;
 

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ExceptionHolder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ExceptionHolder.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ExceptionHolder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ExceptionHolder.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
 import java.io.IOException;
 import java.io.PrintWriter;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ExceptionMappingInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ExceptionMappingInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/I18nInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/I18nInterceptor.java Thu Dec  1 07:18:07 2011
@@ -14,12 +14,12 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.LocalizedTextUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.LocalizedTextUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.util.Locale;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/Interceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/Interceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/LoggingInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/LoggingInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,11 +13,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/MethodFilterInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/MethodFilterInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/MethodFilterInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/MethodFilterInterceptor.java Thu Dec  1 07:18:07 2011
@@ -14,12 +14,12 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.util.Collections;
 import java.util.Set;
@@ -65,8 +65,8 @@ import java.util.Set;
  * 
  * @see org.apache.struts2.interceptor.TokenInterceptor
  * @see org.apache.struts2.interceptor.TokenSessionStoreInterceptor
- * @see com.opensymphony.xwork2.interceptor.DefaultWorkflowInterceptor
- * @see com.opensymphony.xwork2.validator.ValidationInterceptor
+ * @see org.apache.struts2.xwork2.interceptor.DefaultWorkflowInterceptor
+ * @see org.apache.struts2.xwork2.validator.ValidationInterceptor
  * 
  * @version $Date$ $Id$
  */

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/MethodFilterInterceptorUtil.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/MethodFilterInterceptorUtil.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/MethodFilterInterceptorUtil.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/MethodFilterInterceptorUtil.java Thu Dec  1 07:18:07 2011
@@ -13,10 +13,10 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.WildcardHelper;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.WildcardHelper;
 
 import java.util.HashMap;
 import java.util.Iterator;
@@ -24,7 +24,7 @@ import java.util.Set;
 
 /**
  * Utility class contains common methods used by 
- * {@link com.opensymphony.xwork2.interceptor.MethodFilterInterceptor}.
+ * {@link org.apache.struts2.xwork2.interceptor.MethodFilterInterceptor}.
  * 
  * @author tm_jee
  */

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ModelDrivenInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ModelDrivenInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ModelDrivenInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ModelDrivenInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,12 +13,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ModelDriven;
-import com.opensymphony.xwork2.util.CompoundRoot;
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ModelDriven;
+import org.apache.struts2.xwork2.util.CompoundRoot;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/NoParameters.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/NoParameters.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/NoParameters.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/NoParameters.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParameterFilterInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParameterFilterInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParameterFilterInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParameterFilterInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,12 +13,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.util.Collection;
 import java.util.HashSet;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParameterNameAware.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParameterNameAware.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParameterNameAware.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParameterNameAware.java Thu Dec  1 07:18:07 2011
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParameterRemoverInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParameterRemoverInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParameterRemoverInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParameterRemoverInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,13 +13,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.util.Collections;
 import java.util.Map;
@@ -92,7 +92,7 @@ public class ParameterRemoverInterceptor
 	 * Decide if the parameter should be removed from the parameter map based on
 	 * <code>paramNames</code> and <code>paramValues</code>.
 	 * 
-	 * @see com.opensymphony.xwork2.interceptor.AbstractInterceptor
+	 * @see org.apache.struts2.xwork2.interceptor.AbstractInterceptor
 	 */
 	@Override
 	public String intercept(ActionInvocation invocation) throws Exception {

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParametersInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParametersInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParametersInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ParametersInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,23 +13,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.ValidationAware;
-import com.opensymphony.xwork2.conversion.impl.InstantiatingNullHandler;
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ClearableValueStack;
-import com.opensymphony.xwork2.util.LocalizedTextUtil;
-import com.opensymphony.xwork2.util.MemberAccessValueStack;
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.ValueStackFactory;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionContextState;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ValidationAware;
+import org.apache.struts2.xwork2.conversion.impl.InstantiatingNullHandler;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ClearableValueStack;
+import org.apache.struts2.xwork2.util.LocalizedTextUtil;
+import org.apache.struts2.xwork2.util.MemberAccessValueStack;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStackFactory;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionContextState;
 
 import java.util.Collection;
 import java.util.Collections;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/PreResultListener.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/PreResultListener.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/InstantiatingNullHandler.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/InstantiatingNullHandler.java Thu Dec  1 07:18:07 2011
@@ -13,16 +13,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.conversion.impl;
+package org.apache.struts2.xwork2.conversion.impl;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.conversion.NullHandler;
-import com.opensymphony.xwork2.conversion.ObjectTypeDeterminer;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionContextState;
-import com.opensymphony.xwork2.util.reflection.ReflectionProvider;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.conversion.NullHandler;
+import org.apache.struts2.xwork2.conversion.ObjectTypeDeterminer;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionContextState;
+import org.apache.struts2.xwork2.util.reflection.ReflectionProvider;
 
 import java.beans.PropertyDescriptor;
 import java.util.*;
@@ -32,7 +32,7 @@ import java.util.*;
  * <!-- START SNIPPET: javadoc -->
  *
  * Provided that the key {@link ReflectionContextState#CREATE_NULL_OBJECTS} is in the action context with a value of true (this key is set
  * only during the execution of the {@link com.opensymphony.xwork2.interceptor.ParametersInterceptor}), OGNL expressions
  * that have caused a NullPointerException will be temporarily stopped for evaluation while the system automatically
  * tries to solve the null references by automatically creating the object.
  *
@@ -32,7 +32,7 @@ import java.util.*;
  *
  * Provided that the key {@link ReflectionContextState#CREATE_NULL_OBJECTS} is in the action context with a value of true (this key is set
- * only during the execution of the {@link com.opensymphony.xwork2.interceptor.ParametersInterceptor}), OGNL expressions
+ * only during the execution of the {@link org.apache.struts2.xwork2.interceptor.ParametersInterceptor}), OGNL expressions
  * that have caused a NullPointerException will be temporarily stopped for evaluation while the system automatically
  * tries to solve the null references by automatically creating the object.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/XWorkBasicConverter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/conversion/impl/XWorkBasicConverter.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizablePhantomReference.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizablePhantomReference.java Thu Dec  1 07:18:07 2011
@@ -14,12 +14,12 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject.util;
+package org.apache.struts2.xwork2.inject.util;
 
 import java.lang.ref.PhantomReference;
 
 /**
  * Phantom reference with a {@link com.opensymphony.xwork2.inject.util.FinalizableReference#finalizeReferent() finalizeReferent()} method which a
  * background thread invokes after the garbage collector reclaims the
  * referent. This is a simpler alternative to using a {@link
  * java.lang.ref.ReferenceQueue}.
@@ -14,12 +14,12 @@
 
 /**
- * Phantom reference with a {@link com.opensymphony.xwork2.inject.util.FinalizableReference#finalizeReferent() finalizeReferent()} method which a
+ * Phantom reference with a {@link org.apache.struts2.xwork2.inject.util.FinalizableReference#finalizeReferent() finalizeReferent()} method which a
  * background thread invokes after the garbage collector reclaims the
  * referent. This is a simpler alternative to using a {@link

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableReference.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableReference.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableSoftReference.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableSoftReference.java Thu Dec  1 07:18:07 2011
@@ -14,12 +14,12 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject.util;
+package org.apache.struts2.xwork2.inject.util;
 
 import java.lang.ref.SoftReference;
 
 /**
  * Soft reference with a {@link com.opensymphony.xwork2.inject.util.FinalizableReference#finalizeReferent() finalizeReferent()} method which a background
  * thread invokes after the garbage collector reclaims the referent. This is a
  * simpler alternative to using a {@link java.lang.ref.ReferenceQueue}.
  *
@@ -14,12 +14,12 @@
 
 /**
- * Soft reference with a {@link com.opensymphony.xwork2.inject.util.FinalizableReference#finalizeReferent() finalizeReferent()} method which a background
+ * Soft reference with a {@link org.apache.struts2.xwork2.inject.util.FinalizableReference#finalizeReferent() finalizeReferent()} method which a background
  * thread invokes after the garbage collector reclaims the referent. This is a
  * simpler alternative to using a {@link java.lang.ref.ReferenceQueue}.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableWeakReference.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableWeakReference.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableWeakReference.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/FinalizableWeakReference.java Thu Dec  1 07:18:07 2011
@@ -14,12 +14,12 @@
  * limitations under the License.
  */
 
-package com.opensymphony.xwork2.inject.util;
+package org.apache.struts2.xwork2.inject.util;
 
 import java.lang.ref.WeakReference;
 
 /**
  * Weak reference with a {@link com.opensymphony.xwork2.inject.util.FinalizableReference#finalizeReferent() finalizeReferent()} method which a background
  * thread invokes after the garbage collector reclaims the referent. This is a
  * simpler alternative to using a {@link java.lang.ref.ReferenceQueue}.
  *
@@ -14,12 +14,12 @@
 
 /**
- * Weak reference with a {@link com.opensymphony.xwork2.inject.util.FinalizableReference#finalizeReferent() finalizeReferent()} method which a background
+ * Weak reference with a {@link org.apache.struts2.xwork2.inject.util.FinalizableReference#finalizeReferent() finalizeReferent()} method which a background
  * thread invokes after the garbage collector reclaims the referent. This is a
  * simpler alternative to using a {@link java.lang.ref.ReferenceQueue}.

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/Function.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/inject/util/Function.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ExceptionMappingInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/ExceptionMappingInterceptor.java Thu Dec  1 07:18:07 2011
@@ -13,12 +13,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.config.entities.ExceptionMappingConfig;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.config.entities.ExceptionMappingConfig;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 import java.util.List;
 
@@ -64,7 +64,7 @@ import java.util.List;
  * <!-- START SNIPPET: extending -->
  *
  * If you want to add custom handling for publishing the Exception, you may override
  * {@link #publishException(com.opensymphony.xwork2.ActionInvocation, ExceptionHolder)}. The default implementation
  * pushes the given ExceptionHolder on value stack. A custom implementation could add additional logging etc.
  *
  * <!-- END SNIPPET: extending -->
@@ -64,7 +64,7 @@ import java.util.List;
  *
  * If you want to add custom handling for publishing the Exception, you may override
- * {@link #publishException(com.opensymphony.xwork2.ActionInvocation, ExceptionHolder)}. The default implementation
+ * {@link #publishException(org.apache.struts2.xwork2.ActionInvocation, ExceptionHolder)}. The default implementation
  * pushes the given ExceptionHolder on value stack. A custom implementation could add additional logging etc.
  *

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/I18nInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/I18nInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/Interceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/Interceptor.java Thu Dec  1 07:18:07 2011
@@ -13,9 +13,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionInvocation;
 
 import java.io.Serializable;
 
@@ -39,7 +39,7 @@ import java.io.Serializable;
  * <p/>
  * Interceptors <b>must</b> be stateless and not assume that a new instance will be created for each request or Action.
  * Interceptors may choose to either short-circuit the {@link ActionInvocation} execution and return a return code
  * (such as {@link com.opensymphony.xwork2.Action#SUCCESS}), or it may choose to do some processing before
  * and/or after delegating the rest of the procesing using {@link ActionInvocation#invoke()}.
  * <p/>
  * <!-- END SNIPPET: introduction -->
@@ -195,7 +195,7 @@ public interface Interceptor extends Ser
 
     /**
      * Called after an interceptor is created, but before any requests are processed using
-     * {@link #intercept(com.opensymphony.xwork2.ActionInvocation) intercept} , giving
+     * {@link #intercept(org.apache.struts2.xwork2.ActionInvocation) intercept} , giving
      * the Interceptor a chance to initialize any needed resources.
      */
     void init();
@@ -206,7 +206,7 @@ public interface Interceptor extends Ser
      *
      * @param invocation the action invocation
      * @return the return code, either returned from {@link ActionInvocation#invoke()}, or from the interceptor itself.
      * @throws Exception any system-level error, as defined in {@link com.opensymphony.xwork2.Action#execute()}.
      */
     String intercept(ActionInvocation invocation) throws Exception;
 
@@ -39,7 +39,7 @@ import java.io.Serializable;
  * Interceptors <b>must</b> be stateless and not assume that a new instance will be created for each request or Action.
  * Interceptors may choose to either short-circuit the {@link ActionInvocation} execution and return a return code
- * (such as {@link com.opensymphony.xwork2.Action#SUCCESS}), or it may choose to do some processing before
+ * (such as {@link org.apache.struts2.xwork2.Action#SUCCESS}), or it may choose to do some processing before
  * and/or after delegating the rest of the procesing using {@link ActionInvocation#invoke()}.
  * <p/>
@@ -206,7 +206,7 @@ public interface Interceptor extends Ser
      * @param invocation the action invocation
      * @return the return code, either returned from {@link ActionInvocation#invoke()}, or from the interceptor itself.
-     * @throws Exception any system-level error, as defined in {@link com.opensymphony.xwork2.Action#execute()}.
+     * @throws Exception any system-level error, as defined in {@link org.apache.struts2.xwork2.Action#execute()}.
      */
     String intercept(ActionInvocation invocation) throws Exception;

Modified: struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/LoggingInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/LoggingInterceptor.java?rev=1208981&r1=1208980&r2=1208981&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/PreResultListener.java (original)
+++ struts/struts2/branches/STRUTS_3_X/xwork-core/src/main/java/com/opensymphony/xwork2/interceptor/PreResultListener.java Thu Dec  1 07:18:07 2011
@@ -13,14 +13,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package com.opensymphony.xwork2.interceptor;
+package org.apache.struts2.xwork2.interceptor;
 
-import com.opensymphony.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionInvocation;
 
 
 /**
  * PreResultListeners may be registered with an {@link ActionInvocation} to get a callback after the
- * {@link com.opensymphony.xwork2.Action} has been executed but before the {@link com.opensymphony.xwork2.Result}
+ * {@link org.apache.struts2.xwork2.Action} has been executed but before the {@link org.apache.struts2.xwork2.Result}
  * is executed.
  *
  * @author Jason Carreira
@@ -28,8 +28,8 @@ import com.opensymphony.xwork2.ActionInv
 public interface PreResultListener {
 
     /**
      * This callback method will be called after the {@link com.opensymphony.xwork2.Action} execution and
      * before the {@link com.opensymphony.xwork2.Result} execution.
      *
      * @param invocation  the action invocation
      * @param resultCode  the result code returned by the action (eg. <code>success</code>).
@@ -28,8 +28,8 @@ import com.opensymphony.xwork2.ActionInv
 
     /**
-     * This callback method will be called after the {@link com.opensymphony.xwork2.Action} execution and
-     * before the {@link com.opensymphony.xwork2.Result} execution.
+     * This callback method will be called after the {@link org.apache.struts2.xwork2.Action} execution and
+     * before the {@link org.apache.struts2.xwork2.Result} execution.
      *
      * @param invocation  the action invocation